@@ -1,6 +1,7 @@
 package Import::Base;
 # ABSTRACT: Import a set of modules into the calling module
-$Import::Base::VERSION = '1.002';
+our $VERSION = '1.003';
+
 use strict;
 use warnings;
 use mro ();
@@ -199,7 +200,7 @@ Import::Base - Import a set of modules into the calling module
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
@@ -743,7 +744,8 @@ the consuming class by looking for the Dancer DSL. Because Import::Base uses
 Module::Runtime to load the class, Dancer::Plugin thinks Module::Runtime is
 the calling class, sees there is no DSL to register itself with, and bails.
 
-See L<https://github.com/PerlDancer/Dancer2/pull/1136> for more information.
+This issue was fixed in Dancer2 v0.200000 (released 2016-05-31). See
+L<https://github.com/PerlDancer/Dancer2/pull/1136> for more information.
 
 =back
 
@@ -792,15 +794,25 @@ This one also requires configuration files in a home directory, so is not shippa
 
 Doug Bell <preaction@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Brian Medley
+=for stopwords Brian Medley Doug Bell
+
+=over 4
+
+=item *
 
 Brian Medley <pub-github@bmedley.org>
 
+=item *
+
+Doug Bell <doug@preaction.me>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2017 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
